import Helper from '@ember/component/helper';
import { addListener, removeListener } from '@ember/object/events';

function _toPrimitive(t, r) {
  if ("object" != typeof t || !t) return t;
  var e = t[Symbol.toPrimitive];
  if (void 0 !== e) {
    var i = e.call(t, r || "default");
    if ("object" != typeof i) return i;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r ? String : Number)(t);
}
function _toPropertyKey(t) {
  var i = _toPrimitive(t, "string");
  return "symbol" == typeof i ? i : String(i);
}
function _defineProperty(obj, key, value) {
  key = _toPropertyKey(key);
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }
  return obj;
}

// We define these explicitly rather than using `Parameters<typeof addListener>`
// because `addListener`'s arguments were typed incorrectly in earlier preview
// versions of Ember types.

class AddListenerHelper extends Helper {
  constructor(...args) {
    super(...args);
    _defineProperty(this, "removeListener", void 0);
  }
  compute(args) {
    this.checkRemoveListener();
    const [obj, eventName, target, method, once] = args;
    // method and once are optional
    if (!obj || !eventName || !target) {
      return undefined;
    }
    addListener(obj, eventName, target, method, once);
    this.removeListener = () => removeListener(obj, eventName, target, method);
    return undefined;
  }
  willDestroy() {
    this.checkRemoveListener();
    super.willDestroy();
  }
  checkRemoveListener() {
    if (this.removeListener) {
      this.removeListener();
      delete this.removeListener;
    }
  }
}

export { AddListenerHelper as default };
//# sourceMappingURL=add-listener.js.map
